Change log
==========

`Next version`_
~~~~~~~~~~~~~~~


`0.1`_ (2017-06-20)
~~~~~~~~~~~~~~~~~~~

- Initial public version.

.. _0.1: https://github.com/matthiask/django-cabinet/commit/06f30791f3d
.. _0.2: https://github.com/matthiask/django-cabinet/compare/0.1...0.2
.. _Next version: https://github.com/matthiask/django-cabinet/compare/0.1...master
